/**************************************************************
 * company：Hiwonder
 * 20200617 Aiden
 * Ranging alarm：The closer the object is detected to the ultrasonic, the faster the ultrasonic lights flash
 * The light will flash quickly between 30-160mm (every time/0.5s), and the dot matrix will flash synchronously
 * Slow flashing in other areas (every time/2s), dot matrix goes out
**************************************************************/

/*
  -----------------Note----------------------
  Date: 01-23-2021
  Project Name: MrK_Hiwonder_Hex_V1
  Goal: MrK_Radio_Module_Reciever testing
  Author: Khang Nguyen           
*/

#include <Wire.h>
#include "Servo.h"
#include "WMMatrixLed.h"
#include "SoftwareSerial.h"
#include "LobotServoController.h"

#define rxPin 9  //Serial communication interface between arduino and servo controller
#define txPin 8  

#define DIN  A0  //Dot matrix interface
#define CLK  A1

#define Front_LED 3
#define Back_LED 2

#define I2C_ADDR    0x77

//Rigister
#define DISDENCE_L    0//Lower 8 bits of distance, unit mm
#define DISDENCE_H    1

#define RGB_WORK_MODE 2

#define RGB1_R      3//R value of No.1 light，0~255，Default is 0
#define RGB1_G      4//Default is 0
#define RGB1_B      5//Default is 255

#define RGB2_R      6//R value of No.2 light，0~255，Default is 0
#define RGB2_G      7//Default 0
#define RGB2_B      8//Default 255

#define RGB1_R_BREATHING_CYCLE      9 //In the breathing light mode, the breathing cycle of the R of the No. 1light, the unit is 100ms and the default is 0.
                                      //If the period is set to 3000ms, the value is 30
#define RGB1_G_BREATHING_CYCLE      10
#define RGB1_B_BREATHING_CYCLE      11

#define RGB2_R_BREATHING_CYCLE      12//RGB 2
#define RGB2_G_BREATHING_CYCLE      13
#define RGB2_B_BREATHING_CYCLE      14

#define RGB_WORK_SIMPLE_MODE    0 //RGB mode，0: User-defined mode 1: Breathing light mode Default 0
#define RGB_WORK_BREATHING_MODE   1


SoftwareSerial MySerial(rxPin, txPin);  //Software serial port instantiation

WMMatrixLed matrixLed(CLK, DIN);  //Instantiated dot matrix
LobotServoController Controller(MySerial); //Instantiated secondary development

const int sensorPin = 2;

void setup() 
{
  Wire.begin();
  MySerial.begin(9600);  //Software serial port for communication with servo, baud rate 9600
  Serial.begin(9600);    //Hardware serial port used for printing and debugging, the baud rate is 9600
  matrixLed.setBrightness(2); //The dot matrix brightness is set to 3. Note that the dot matrix brightness cannot be greater than 3, otherwise it will cause excessive current and the arduino to restart repeatedly
  matrixLed.clearScreen(); //Clean screen
  
  Hex_LED_Setup();
  
 Controller.runActionGroup(0, 0); //Run No.0 action group

  //Prompt when initialization is complete
  uint8_t drawBuffer[16] = {
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
  , 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00};
  for (int i = 0; i < 16; i++) {
    drawBuffer[i] = 0xff;
    matrixLed.drawBitmap(0,0,16,drawBuffer);   
    delay(20);
  }  
  
  matrixLed.clearScreen();

}


void loop() 
{
  uint8_t RGB[6];
  uint8_t breathing[6];
  uint8_t value;  
  static uint32_t Time;
  static int timer;

  int lightVal;
  lightVal = analogRead(sensorPin);
  Serial.println(lightVal);
  delay(50);

//  //Set to blink every 0.5s between0-160 light level 
  if (lightVal > 0 && lightVal < 10) 
  {

            uint8_t drawBuffer_[16] = {
               0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
             , 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
      }; //Clear
      matrixLed.drawBitmap(0,0,16,drawBuffer_);
      delay(500); 
      
      uint8_t drawBuffer[16] = {
      0x0,0x0,0x0,0x70,0xf8,0xfc,0xfe,0x7f
      ,0x7f,0xfe,0xfc,0xf8,0x70,0x0,0x0,0x0};
      matrixLed.drawBitmap(0,0,16,drawBuffer); //Heart Shape
      delay(500);
      
  }

  if (lightVal>100)
  {
    Hex_Looking();
//    timer = random(16,32);
//    MatrixLedBlink(timer*1000);
  }
  
  else {//In other intervals, the dot matrix is off, and the blinking 
   uint8_t drawBuffer[16] ={
         0xff, 0x83, 0x01, 0x80, 0x88, 0x80, 0x01, 0xff, 
                                                  0xff, 0x01, 0x80, 0x88, 0x80, 0x01,0x83, 0xff //look center 
   };

    matrixLed.drawBitmap(0,0,16,drawBuffer);
  }

  //Allowed to enter again only after the waiting is over. There is no "delay" here. "Delay" is a blocking delay and cannot always detect the distance.
  if (Time > millis())
    return;

 
  Time = millis() + timer*100;

   matrixLed.clearScreen();
}

int Hex_LED_Setup()
{
 pinMode(Front_LED, OUTPUT); // setup LED 
 pinMode(Back_LED, OUTPUT);
  analogWrite(Front_LED, 250); 
  digitalWrite(Back_LED, HIGH);  
  delay(1000);                       
  analogWrite(Front_LED, 100);    
  delay(100); 
}


void MatrixLedBlink(uint8_t t) {
  static uint32_t Time = 0;
  static bool ledStatus = false;
  if (Time > millis()) {
    return;
  }

  if (!ledStatus) {//turn on light
    //The dot matrix is 16x8. Each parameter in the list below represents a column, from left to right.
    //Each column is represented by a hexadecimal number. The first one is represented by binary when it is lit from bottom to top, the second is 10, and the third is 100. At the same time, the first is lit, and the second is 11. And so on
    //Then convert the binary number to hexadecimal.
 
   
   uint8_t drawBuffer[16] ={
         0xff, 0x83, 0x01, 0x80, 0x80, 0x88, 0x01, 0xff, 
                                                  0xff, 0x01, 0x80, 0x80, 0x88, 0x01,0x83, 0xff //look left                                         
    };
    matrixLed.drawBitmap(0,0,16,drawBuffer); 
  }
  else {
    uint8_t drawBuffer_[16] = {
               0xff, 0x83, 0x01, 0x80, 0x88, 0x80, 0x01, 0xff, 
                                                  0xff, 0x01, 0x80, 0x88, 0x80, 0x01,0x83, 0xff //look center 
    };
    matrixLed.drawBitmap(0,0,16,drawBuffer_);
  }
  ledStatus = !ledStatus;
  Time = millis() + t;
  
} 
//uint8_t drawBuffer_[16] = {
//                0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
//               ,0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
//
//};
//matrixLed.drawBitmap(0,0,16,drawBuffer_);
//}

int Hex_Looking()
{
  int S_Random = random(0,300);

  if(S_Random >=0 && S_Random < 100)
  {
        uint8_t drawBuffer_[16] = {
               0xff, 0x83, 0x01, 0x80, 0x88, 0x80, 0x01, 0xff, 
               0xff, 0x01, 0x80, 0x88, 0x80, 0x01,0x83, 0xff }; //look center
         matrixLed.drawBitmap(0,0,16,drawBuffer_);
         delay(500);
  }
    if(S_Random >=100 && S_Random < 200)
  {
        uint8_t drawBuffer_[16] = {
         0xff, 0x83, 0x01, 0x80, 0x80, 0x88, 0x01, 0xff, 
         0xff, 0x01, 0x80, 0x80, 0x88, 0x01,0x83, 0xff };//look left    
         matrixLed.drawBitmap(0,0,16,drawBuffer_);
         delay(500);
  }
      if(S_Random >=200 && S_Random < 300)
  {
        uint8_t drawBuffer_[16] = {
         0xff, 0x83, 0x01, 0x88, 0x80, 0x80, 0x01, 0xff, 
         0xff, 0x01, 0x80, 0x88, 0x80, 0x01,0x83, 0xff };//look right    
         matrixLed.drawBitmap(0,0,16,drawBuffer_);
         delay(500);
  }
}
